/*
 * Copyright 2011-2019 Arx Libertatis Team (see the AUTHORS file)
 *
 * This file is part of Arx Libertatis.
 *
 * Arx Libertatis is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Arx Libertatis is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Arx Libertatis.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "core/Version.h"

/*!
 * This file is automatically processed by cmake if the version or commit id changes.
 * For the exact syntax see the documentation of the configure_file() cmake command.
 * For available variables see cmake/VersionString.cmake.
 */

#define ARX_VERSION_LINE_COUNT 6
#if ARX_VERSION_LINE_COUNT != 6 && ARX_VERSION_LINE_COUNT != 7
#error "Configure error - the VERSION file should specify 6 or 7 non-empty lines!"
#endif

const std::string arx_name = "Arx Libertatis";
const std::string arx_icon_name = "arx-libertatis";
const std::string arx_version = "1.3-dev";
const u64 arx_version_number = (u64(1) << 48) | (u64(2) << 32)
                             | (u64(9999) << 16) | (u64(9999) << 0);
/* #undef VERSION_6 */
#ifdef VERSION_6
const std::string arx_release_codename = "";
#else
const std::string arx_release_codename;
#endif

// TODO move this to an external file once we ship our own resources
const std::string arx_credits = "~Thanks for playing Arx Libertatis!\n"
	"\n"
	"This version of Arx Fatalis has been created by various community members in their spare time.\n"
	"We welcome your criticism, suggestions and contributions!\n"
	"You can find us at https://arx-libertatis.org/\n"
	"\n"
	"\n"
	"~ARX LIBERTATIS CONTRIBUTORS\n"
	"\n"
	"Erik Lund (Akhilla)\n"
	"Sebastien Lussier (BobJelly)\n"
	"Fabian Roth (Eli2)\n"
	"Lubosz Sarnecki (lubosz)\n"
	"Daniel Scharrer (ds)\n"
	"David Stejskal (bsxf47)\n"
	"\n"
	"~Additional code by:\n"
	"\n"
	"Darren Bane\n"
	"Philippe Cavalaria (Nuky)\n"
	"Gabriel Cuvillier\n"
	"R D (rdragan)\n"
	"Dimoks\n"
	"dreamer.dead\n"
	"Adrian Fuhrmann\n"
	"Frederik Gelder\n"
	"Chris Gray (chrismgray)\n"
	"guidoj\n"
	"HelenWong\n"
	"Thomas Leroy (LordSk)\n"
	"Dmitry Marakasov (AMDmi3)\n"
	"Alex Marginean (Alex M.)\n"
	"Lajos Mészáros (NodenGaming)\n"
	"David Michael\n"
	"nemyax\n"
	"Olli Numminen (Olzaq)\n"
	"Alibek Omarov\n"
	"Jonathan Powell (jfpowell)\n"
	"QJa42FMM\n"
	"Jean-Francois Richard\n"
	"Elliot Rigets (adejr)\n"
	"r-a-sattarov\n"
	"Tafferwocky\n"
	"Gerasim Troeglazov (threedeyes)\n"
	"Rémi Verschelde\n"
	"xanm\n"
	"XoD\n"
	"YetiWizard\n"
	"\n"
	"~German translation by:\n"
	"\n"
	"Fabian Roth (Eli2)\n"
	"Daniel Scharrer (ds)\n"
	"\n"
	"~Hungarian translation by:\n"
	"\n"
	"Mortens4444\n"
	"\n"
	"~Italian translation by:\n"
	"\n"
	"Lorenza Mucci\n"
	"steinuil\n"
	"Lauriel\n"
	"\n"
	"~Russian translation by:\n"
	"\n"
	"Gleb Rodin (Interval)\n"
	"N1Nikita\n"
	"nemyax\n"
	"Lauriel\n"
	"\n"
	"~Spanish translation by:\n"
	"\n"
	"Pedro Ordaz (Executiommentary)\n"
	"steinuil\n"
	"\n"
	"~Arx Libertatis has been packaged by:\n"
	"\n"
	"Nikolay Amiantov (abbradar)\n"
	"Bo Anderson (Bo98)\n"
	"Andrey Bondrov\n"
	"Sam Ford\n"
	"Thomas Frohwein\n"
	"gcala\n"
	"Andrey Grigorev (survolog)\n"
	"Yorick Hardy\n"
	"Nanda H Krishna (nandahkrishna)\n"
	"Clément L. (Porkepix)\n"
	"d10sfan\n"
	"fgsfds\n"
	"hasufell\n"
	"Dmitry Marakasov (AMDmi3)\n"
	"Arseny Maslennikov\n"
	"Beatrice T. Meyers (DataDrake)\n"
	"Misty De Méo\n"
	"Anton Midyukov (antohami)\n"
	"Pierre Neidhardt\n"
	"ptitSeb\n"
	"Michele Guerini Rocco (rnhmjoj)\n"
	"Daniel Scharrer (ds)\n"
	"Jonathan Schleifer\n"
	"smls\n"
	"Thomas Staudinger (Staudey)\n"
	"Joshua Strobl (JoshStrobl)\n"
	"symbianflo\n"
	"TheGoliath\n"
	"Gerasim Troeglazov (threedeyes)\n"
	"Rémi Verschelde (Akien)\n"
	"Dimitris Zlatanidis\n"
	"\n"
	"~Many thanks to:\n"
	"All our users, testers, bug reporters and everyone else who has supported the project, including\n"
	"\n"
	"barra\n"
	"coffey_rt\n"
	"DaveMachine\n"
	"Alexandre Detiste (a-detiste)\n"
	"Dimoks\n"
	"HiPhish\n"
	"i30817\n"
	"Keyhaku\n"
	"Lorenza (Lauriel)\n"
	"Lajos Mészáros (NodenGaming)\n"
	"Nacery\n"
	"nemyax\n"
	"Jan-Hendrik Peters\n"
	"qubodup\n"
	"Raggo\n"
	"Elliot Rigets (adejr)\n"
	"Rocker\n"
	"Gleb Rodin (Interval)\n"
	"RoSoDude\n"
	"Tafferwocky\n"
	"Telendil\n"
	"vytautas (aka. ProzacR)\n"
	"xanm\n"
	"\n"
	"~Special thanks to\n"
	"\n"
	"Arnaud David\n"
	"\n"
	"As well as everyone else at Arkane Studios\n"
	"\n"
	"For making this project possible by creating Arx Fatalis, releasing the source code and answering our questions";
const std::string arx_copyright = "~Arx Libertatis is free software:\n"
	"You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version (see the LICENSE file for details). Some parts of the source code are available under more permissive licenses.\n"
	"Copyright (C) 2011-2023 Arx Libertatis Team and Contributors.\n"
	"\n"
	"Arx Libertatis is based on the Arx Fatalis GPLv3 source code.\n"
	"Copyright (C) 1999-2010 Arkane Studios SA, a ZeniMax Media company.\n"
	"\n"
	"Arx Libertatis makes use of the stb_image library.\n"
	"Copyright (C) Sean T. Barrett. See the LICENSE.stb file for details.\n"
	"\n"
	"Arx Libertatis makes use of the fast_float number parsing library.\n"
	"Copyright (C) Daniel Lemire and João Paulo Magalhaes. See the LICENSE.fast_float file for details.\n"
	"\n"
	"Arx Libertatis makes use of DejaVu fonts, based on the Bitstream Vera fonts (c) Bitstream. DejaVu changes are in public domain. Glyphs imported from Arev fonts are (c) Tavmjong Bah. See the LICENSE.DejaVu file for details.\n"
	"\n"
	"Arx Libertatis makes use of Noto fonts published under the SIL Open Font License (OFL) v1.1.";

const std::string cmake_version = "3.27.7";

const int tbg_version_id = 11;
